@@ -27,6 +27,7 @@ enum swErrorCode
     SW_ERROR_PHP_FATAL_ERROR,
     SW_ERROR_NAME_TOO_LONG,
     SW_ERROR_INVALID_PARAMS,
+    SW_ERROR_QUEUE_FULL,
 
     SW_ERROR_FILE_NOT_EXIST = 700,
     SW_ERROR_FILE_TOO_LARGE,
@@ -103,12 +104,31 @@ enum swErrorCode
     SW_ERROR_SERVER_NO_IDLE_WORKER,
 
     SW_ERROR_SERVER_ONLY_START_ONE,
+    SW_ERROR_SERVER_SEND_IN_MASTER,
 
     /**
      * Process exit timeout, forced to end.
      */
     SW_ERROR_SERVER_WORKER_EXIT_TIMEOUT,
 
+    /**
+     * Coroutine
+     */
+    SW_ERROR_CO_MUTEX_DOUBLE_UNLOCK = 10001,
+    SW_ERROR_CO_BLOCK_OBJECT_LOCKED,
+    SW_ERROR_CO_BLOCK_OBJECT_WAITING,
+    SW_ERROR_CO_YIELD_FAILED,
+    SW_ERROR_CO_GETCONTEXT_FAILED,
+    SW_ERROR_CO_SWAPCONTEXT_FAILED,
+    SW_ERROR_CO_MAKECONTEXT_FAILED,
+
+    SW_ERROR_CO_IOCPINIT_FAILED,
+    SW_ERROR_CO_PROTECT_STACK_FAILED,
+    SW_ERROR_CO_STD_THREAD_LINK_ERROR,
+    SW_ERROR_CO_DISABLED_MULTI_THREAD,
+
 };
 
+void swoole_throw_error(enum swErrorCode code);
+
 #endif /* SW_ERRNO_H_ */
