@@ -50,7 +50,7 @@
 
 BEGIN_EXTERN_C()
 
-#define PHP_SWOOLE_VERSION  "4.0.3"
+#define PHP_SWOOLE_VERSION  "4.0.4"
 #define PHP_SWOOLE_CHECK_CALLBACK
 #define PHP_SWOOLE_ENABLE_FASTCALL
 #define PHP_SWOOLE_CLIENT_USE_POLL
@@ -220,6 +220,10 @@ enum php_swoole_fd_type
     PHP_SWOOLE_FD_SOCKET,
     PHP_SWOOLE_FD_CHAN_PIPE,
 #endif
+    /**
+     * for Co::fread/Co::fwrite
+     */
+    PHP_SWOOLE_FD_CO_UTIL,
 };
 //---------------------------------------------------------
 typedef enum
@@ -263,7 +267,6 @@ PHP_FUNCTION(swoole_set_process_name);
 PHP_FUNCTION(swoole_get_local_ip);
 PHP_FUNCTION(swoole_get_local_mac);
 PHP_FUNCTION(swoole_call_user_shutdown_begin);
-PHP_FUNCTION(swoole_unsupport_serialize);
 PHP_FUNCTION(swoole_coroutine_create);
 PHP_FUNCTION(swoole_coroutine_exec);
 
@@ -463,7 +466,8 @@ static sw_inline void* swoole_get_property(zval *object, int property_id)
 
 void swoole_set_object(zval *object, void *ptr);
 void swoole_set_property(zval *object, int property_id, void *ptr);
-int swoole_convert_to_fd(zval *zsocket TSRMLS_DC);
+int swoole_convert_to_fd(zval *zfd TSRMLS_DC);
+int swoole_convert_to_fd_ex(zval *zfd, int *async TSRMLS_DC);
 int swoole_register_rshutdown_function(swCallback func, int push_back);
 void swoole_call_rshutdown_function(void *arg);
 
