@@ -51,15 +51,16 @@ int swFactoryProcess_create(swFactory *factory, int worker_num)
 static int swFactoryProcess_shutdown(swFactory *factory)
 {
     int status;
+    swServer *serv = factory->ptr;
 
-    if (swKill(SwooleGS->manager_pid, SIGTERM) < 0)
+    if (swKill(serv->gs->manager_pid, SIGTERM) < 0)
     {
-        swSysError("kill(%d) failed.", SwooleGS->manager_pid);
+        swSysError("kill(%d) failed.", serv->gs->manager_pid);
     }
 
-    if (swWaitpid(SwooleGS->manager_pid, &status, 0) < 0)
+    if (swWaitpid(serv->gs->manager_pid, &status, 0) < 0)
     {
-        swSysError("waitpid(%d) failed.", SwooleGS->manager_pid);
+        swSysError("waitpid(%d) failed.", serv->gs->manager_pid);
     }
 
     return SW_OK;
@@ -115,21 +116,19 @@ static int swFactoryProcess_notify(swFactory *factory, swDataHead *ev)
  */
 static int swFactoryProcess_dispatch(swFactory *factory, swDispatchData *task)
 {
-    uint32_t schedule_key;
     uint32_t send_len = sizeof(task->data.info) + task->data.info.len;
-    uint16_t target_worker_id;
+    int target_worker_id;
     swServer *serv = SwooleG.serv;
     int fd = task->data.info.fd;
 
     if (task->target_worker_id < 0)
     {
-        schedule_key = fd;
 #ifndef SW_USE_RINGBUFFER
         if (SwooleTG.factory_lock_target)
         {
             if (SwooleTG.factory_target_worker < 0)
             {
-                target_worker_id = swServer_worker_schedule(serv, schedule_key);
+                target_worker_id = swServer_worker_schedule(serv, fd, &task->data);
                 SwooleTG.factory_target_worker = target_worker_id;
             }
             else
@@ -140,29 +139,18 @@ static int swFactoryProcess_dispatch(swFactory *factory, swDispatchData *task)
         else
 #endif
         {
-            if (serv->dispatch_mode == SW_DISPATCH_USERFUNC)
-            {
-                int ret = serv->dispatch_func(serv, swServer_connection_get(serv, fd), &task->data);
-                //discard the data packet.
-                if (ret < 0)
-                {
-                    return SW_OK;
-                }
-                else
-                {
-                    target_worker_id = ret;
-                }
-            }
-            else
-            {
-                target_worker_id = swServer_worker_schedule(serv, schedule_key);
-            }
+            target_worker_id = swServer_worker_schedule(serv, fd, &task->data);
         }
     }
     else
     {
         target_worker_id = task->target_worker_id;
     }
+    //discard the data packet.
+    if (target_worker_id < 0)
+    {
+        return SW_OK;
+    }
 
     if (swEventData_is_stream(task->data.info.type))
     {
@@ -234,10 +222,9 @@ static int swFactoryProcess_finish(swFactory *factory, swSendData *resp)
      */
     if (resp->length > 0)
     {
-        if (worker->send_shm == NULL)
+        if (worker == NULL || worker->send_shm == NULL)
         {
-            swWarn("send failed, data is too big.");
-            return SW_ERR;
+            goto pack_data;
         }
 
         //worker process
@@ -249,6 +236,7 @@ static int swFactoryProcess_finish(swFactory *factory, swSendData *resp)
             //cannot use send_shm
             if (!swBuffer_empty(_pipe_socket->out_buffer))
             {
+                pack_data:
                 if (swTaskWorker_large_pack(&ev_data, resp->data, resp->length) < 0)
                 {
                     return SW_ERR;
@@ -282,7 +270,7 @@ static int swFactoryProcess_finish(swFactory *factory, swSendData *resp)
     send_to_reactor_thread: ev_data.info.from_id = conn->from_id;
     sendn = ev_data.info.len + sizeof(resp->info);
 
-    swTrace("[Worker] send: sendn=%d|type=%d|content=%s", sendn, resp->info.type, resp->data);
+    swTrace("[Worker] send: sendn=%d|type=%d|content=<<EOF\n%.*s\nEOF", sendn, resp->info.type, resp->length > 0 ? resp->length : resp->info.len, resp->data);
     ret = swWorker_send2reactor(&ev_data, sendn, session_id);
     if (ret < 0)
     {
@@ -328,7 +316,14 @@ static int swFactoryProcess_end(swFactory *factory, int fd)
         if (serv->onClose != NULL)
         {
             info.fd = fd;
-            info.from_id = -1;
+            if (conn->close_actively)
+            {
+                info.from_id = -1;
+            }
+            else
+            {
+                info.from_id = conn->from_id;
+            }
             info.from_fd = conn->from_fd;
             serv->onClose(serv, &info);
         }
