@@ -755,12 +755,12 @@ int swReactorThread_send(swSendData *_send)
         }
     }
 
-    swBuffer_trunk *trunk;
+    swBuffer_chunk *chunk;
     //close connection
     if (_send->info.type == SW_EVENT_CLOSE)
     {
-        trunk = swBuffer_new_trunk(conn->out_buffer, SW_CHUNK_CLOSE, 0);
-        trunk->store.data.val1 = _send->info.type;
+        chunk = swBuffer_new_chunk(conn->out_buffer, SW_CHUNK_CLOSE, 0);
+        chunk->store.data.val1 = _send->info.type;
     }
     //sendfile to client
     else if (_send->info.type == SW_EVENT_SENDFILE)
@@ -833,7 +833,7 @@ static int swReactorThread_onPipeWrite(swReactor *reactor, swEvent *ev)
 {
     int ret;
 
-    swBuffer_trunk *trunk = NULL;
+    swBuffer_chunk *chunk = NULL;
     swEventData *send_data;
     swConnection *conn;
     swServer *serv = reactor->ptr;
@@ -845,15 +845,15 @@ static int swReactorThread_onPipeWrite(swReactor *reactor, swEvent *ev)
 
     while (!swBuffer_empty(buffer))
     {
-        trunk = swBuffer_get_trunk(buffer);
-        send_data = trunk->store.ptr;
+        chunk = swBuffer_get_chunk(buffer);
+        send_data = chunk->store.ptr;
 
         //server active close, discard data.
         if (swEventData_is_stream(send_data->info.type))
         {
             //send_data->info.fd is session_id
             conn = swServer_connection_verify(serv, send_data->info.fd);
-            if (conn == NULL || conn->closed)
+            if (conn)
             {
 #ifdef SW_USE_RINGBUFFER
                 swReactorThread *thread = swServer_get_thread(SwooleG.serv, SwooleTG.id);
@@ -861,16 +861,22 @@ static int swReactorThread_onPipeWrite(swReactor *reactor, swEvent *ev)
                 memcpy(&package, send_data->data, sizeof(package));
                 thread->buffer_input->free(thread->buffer_input, package.data);
 #endif
-                if (conn && conn->closed)
+                if (conn->closed)
                 {
                     swoole_error_log(SW_LOG_NOTICE, SW_ERROR_SESSION_CLOSED_BY_SERVER, "Session#%d is closed by server.", send_data->info.fd);
+                    _discard: swBuffer_pop_chunk(buffer, chunk);
+                    continue;
                 }
-                swBuffer_pop_trunk(buffer, trunk);
-                continue;
+            }
+            else if (serv->discard_timeout_request)
+            {
+                swoole_error_log(SW_LOG_WARNING, SW_ERROR_SESSION_DISCARD_TIMEOUT_DATA,
+                        "[1]received the wrong data[%d bytes] from socket#%d", send_data->info.len, send_data->info.fd);
+                goto _discard;
             }
         }
 
-        ret = write(ev->fd, trunk->store.ptr, trunk->length);
+        ret = write(ev->fd, chunk->store.ptr, chunk->length);
         if (ret < 0)
         {
             //release lock
@@ -883,7 +889,7 @@ static int swReactorThread_onPipeWrite(swReactor *reactor, swEvent *ev)
         }
         else
         {
-            swBuffer_pop_trunk(buffer, trunk);
+            swBuffer_pop_chunk(buffer, chunk);
         }
     }
 
@@ -972,7 +978,7 @@ static int swReactorThread_onWrite(swReactor *reactor, swEvent *ev)
 {
     int ret;
     swServer *serv = SwooleG.serv;
-    swBuffer_trunk *chunk;
+    swBuffer_chunk *chunk;
     int fd = ev->fd;
 
     if (serv->factory_mode == SW_MODE_PROCESS)
@@ -1047,7 +1053,7 @@ static int swReactorThread_onWrite(swReactor *reactor, swEvent *ev)
 
     _pop_chunk: while (!swBuffer_empty(conn->out_buffer))
     {
-        chunk = swBuffer_get_trunk(conn->out_buffer);
+        chunk = swBuffer_get_chunk(conn->out_buffer);
         if (chunk->type == SW_CHUNK_CLOSE)
         {
             close_fd: reactor->close(reactor, fd);
