@@ -133,6 +133,12 @@ static void* swThreadPool_loop(void *arg)
     int ret;
     void *task;
 
+    SwooleTG.buffer_stack = swString_new(8192);
+    if (SwooleTG.buffer_stack == NULL)
+    {
+        return NULL;
+    }
+
     if (pool->onStart)
     {
         pool->onStart(pool, id);
@@ -145,7 +151,7 @@ static void* swThreadPool_loop(void *arg)
         if (pool->shutdown)
         {
             pool->cond.unlock(&pool->cond);
-            swTrace("thread [%d] will exit\n", id);
+            swTrace("thread [%d] will exit", id);
             pthread_exit(NULL);
         }
 
@@ -154,7 +160,7 @@ static void* swThreadPool_loop(void *arg)
             pool->cond.wait(&pool->cond);
         }
 
-        swTrace("thread [%d] is starting to work\n", id);
+        swTrace("thread [%d] is starting to work", id);
 
         ret = swRingQueue_pop(&pool->queue, &task);
         pool->cond.unlock(&pool->cond);
@@ -173,6 +179,7 @@ static void* swThreadPool_loop(void *arg)
         pool->onStop(pool, id);
     }
 
+    swString_free(SwooleTG.buffer_stack);
     pthread_exit(NULL);
     return NULL;
 }
