@@ -122,9 +122,9 @@ void swWorker_signal_handler(int signo)
 
 static sw_inline int swWorker_discard_data(swServer *serv, swEventData *task)
 {
-    int fd = task->info.fd;
+    int session_id = task->info.fd;
     //check connection
-    swConnection *conn = swServer_connection_verify(serv, task->info.fd);
+    swConnection *conn = swServer_connection_verify(serv, session_id);
     if (conn == NULL)
     {
         if (serv->disable_notify && !serv->discard_timeout_request)
@@ -152,12 +152,12 @@ static sw_inline int swWorker_discard_data(swServer *serv, swEventData *task)
         memcpy(&package, task->data, sizeof(package));
         swReactorThread *thread = swServer_get_thread(SwooleG.serv, task->info.from_id);
         thread->buffer_input->free(thread->buffer_input, package.data);
-        swoole_error_log(SW_LOG_WARNING, SW_ERROR_SESSION_DISCARD_TIMEOUT_DATA, "[1]received the wrong data[%d bytes] from socket#%d", package.length, fd);
+        swoole_error_log(SW_LOG_WARNING, SW_ERROR_SESSION_DISCARD_TIMEOUT_DATA, "[1]received the wrong data[%d bytes] from socket#%d", package.length, session_id);
     }
     else
 #endif
     {
-        swoole_error_log(SW_LOG_WARNING, SW_ERROR_SESSION_DISCARD_TIMEOUT_DATA, "[1]received the wrong data[%d bytes] from socket#%d", task->info.len, fd);
+        swoole_error_log(SW_LOG_WARNING, SW_ERROR_SESSION_DISCARD_TIMEOUT_DATA, "[1]received the wrong data[%d bytes] from socket#%d", task->info.len, session_id);
     }
     return SW_TRUE;
 }
@@ -733,10 +733,6 @@ int swWorker_loop(swFactory *factory, int worker_id)
 #elif defined(HAVE_SIGNALFD)
     SwooleG.use_signalfd = 1;
 #endif
-    //timerfd
-#ifdef HAVE_TIMERFD
-    SwooleG.use_timerfd = 1;
-#endif
 
     //worker_id
     SwooleWG.id = worker_id;
