@@ -19,12 +19,11 @@
 #ifdef HAVE_EPOLL
 #include <sys/epoll.h>
 #ifndef EPOLLRDHUP
-#define EPOLLRDHUP   0x2000
-#define NO_EPOLLRDHUP
+#error "require linux kernel version 2.6.32 or later."
 #endif
 
 #ifndef EPOLLONESHOT
-#define EPOLLONESHOT (1u << 30)
+#error "require linux kernel version 2.6.32 or later."
 #endif
 
 typedef struct swReactorEpoll_s swReactorEpoll;
@@ -52,6 +51,10 @@ static sw_inline int swReactorEpoll_event_set(int fdtype)
     {
         flag |= EPOLLOUT;
     }
+    if (fdtype & SW_EVENT_ONCE)
+    {
+        flag |= EPOLLONESHOT;
+    }
     if (swReactor_event_error(fdtype))
     {
         //flag |= (EPOLLRDHUP);
@@ -269,11 +272,7 @@ static int swReactorEpoll_wait(swReactor *reactor, struct timeval *timeo)
                 }
             }
             //error
-#ifndef NO_EPOLLRDHUP
             if ((events[i].events & (EPOLLRDHUP | EPOLLERR | EPOLLHUP)) && !event.socket->removed)
-#else
-            if ((events[i].events & (EPOLLERR | EPOLLHUP)) && !event.socket->removed)
-#endif
             {
                 //ignore ERR and HUP, because event is already processed at IN and OUT handler.
                 if ((events[i].events & EPOLLIN) || (events[i].events & EPOLLOUT))
@@ -287,6 +286,11 @@ static int swReactorEpoll_wait(swReactor *reactor, struct timeval *timeo)
                     swSysError("EPOLLERR handle failed. fd=%d.", event.fd);
                 }
             }
+            if (!event.socket->removed && (event.socket->events & SW_EVENT_ONCE))
+            {
+                reactor->event_num = reactor->event_num <= 0 ? 0 : reactor->event_num - 1;
+                swReactor_del(reactor, event.fd);
+            }
         }
 
         if (reactor->onFinish != NULL)
