@@ -335,6 +335,39 @@ int swoole_convert_to_fd(zval *zfd TSRMLS_DC)
     return socket_fd;
 }
 
+int swoole_convert_to_fd_ex(zval *zfd, int *async TSRMLS_DC)
+{
+    php_stream *stream;
+    int fd;
+
+#ifdef SWOOLE_SOCKETS_SUPPORT
+    php_socket *php_sock;
+#endif
+
+    if (SW_Z_TYPE_P(zfd) != IS_RESOURCE)
+    {
+        swoole_php_fatal_error(E_WARNING, "fd argument must be either valid PHP stream or valid PHP socket resource");
+        return SW_ERR;
+    }
+    if (SW_ZEND_FETCH_RESOURCE_NO_RETURN(stream, php_stream *, &zfd, -1, NULL, php_file_le_stream()))
+    {
+        if (php_stream_cast(stream, PHP_STREAM_AS_FD_FOR_SELECT | PHP_STREAM_CAST_INTERNAL, (void* )&fd, 1) == SUCCESS && fd >= 0)
+        {
+            *async = stream->wrapper->wops == php_plain_files_wrapper.wops ? 0 : 1;
+            return fd;
+        }
+    }
+#ifdef SWOOLE_SOCKETS_SUPPORT
+    else if (SW_ZEND_FETCH_RESOURCE_NO_RETURN(php_sock, php_socket *, &zfd, -1, NULL, php_sockets_le_socket()))
+    {
+        fd = php_sock->bsd_socket;
+        *async = 1;
+    }
+#endif
+    swoole_php_fatal_error(E_WARNING, "invalid file descriptor passed");
+    return SW_ERR;
+}
+
 #ifdef SWOOLE_SOCKETS_SUPPORT
 php_socket* swoole_convert_to_socket(int sock)
 {
