@@ -23,8 +23,7 @@
 static zend_class_entry swoole_http2_client_ce;
 static zend_class_entry *swoole_http2_client_class_entry_ptr;
 
-static zend_class_entry swoole_http2_response_ce;
-zend_class_entry *swoole_http2_response_class_entry_ptr;
+extern zend_class_entry *swoole_http2_response_class_entry_ptr;
 
 swString *cookie_buffer = NULL;
 
@@ -95,18 +94,6 @@ void swoole_http2_client_init(int module_number TSRMLS_DC)
     zend_declare_property_null(swoole_http2_client_class_entry_ptr, SW_STRL("requestHeaders")-1, ZEND_ACC_PUBLIC TSRMLS_CC);
     zend_declare_property_null(swoole_http2_client_class_entry_ptr, SW_STRL("cookies")-1, ZEND_ACC_PUBLIC TSRMLS_CC);
 
-    SWOOLE_INIT_CLASS_ENTRY(swoole_http2_response_ce, "swoole_http2_response", "Swoole\\Http2\\Response", NULL);
-    swoole_http2_response_class_entry_ptr = zend_register_internal_class(&swoole_http2_response_ce TSRMLS_CC);
-    SWOOLE_CLASS_ALIAS(swoole_http2_response, "Swoole\\Http2\\Response");
-
-    zend_declare_property_long(swoole_http2_response_class_entry_ptr, SW_STRL("errCode")-1, 0, ZEND_ACC_PUBLIC TSRMLS_CC);
-    zend_declare_property_long(swoole_http2_response_class_entry_ptr, SW_STRL("statusCode")-1, 0, ZEND_ACC_PUBLIC TSRMLS_CC);
-    zend_declare_property_null(swoole_http2_response_class_entry_ptr, SW_STRL("headers")-1, ZEND_ACC_PUBLIC TSRMLS_CC);
-    zend_declare_property_null(swoole_http2_response_class_entry_ptr, SW_STRL("set_cookie_headers")-1, ZEND_ACC_PUBLIC TSRMLS_CC);
-    zend_declare_property_null(swoole_http2_response_class_entry_ptr, SW_STRL("cookies")-1, ZEND_ACC_PUBLIC TSRMLS_CC);
-    zend_declare_property_null(swoole_http2_response_class_entry_ptr, SW_STRL("body")-1, ZEND_ACC_PUBLIC TSRMLS_CC);
-    zend_declare_property_long(swoole_http2_response_class_entry_ptr, SW_STRL("streamId")-1, 0, ZEND_ACC_PUBLIC TSRMLS_CC);
-
     if (cookie_buffer == NULL)
     {
         cookie_buffer = swString_new(8192);
@@ -120,6 +107,12 @@ static PHP_METHOD(swoole_http2_client, __construct)
     long port = 80;
     zend_bool ssl = SW_FALSE;
 
+    swoole_php_fatal_error(
+        E_DEPRECATED,
+        "Http2 async client will be removed in the next version, "
+        "please use \\Swoole\\Coroutine\\Http2\\Client instead."
+    );
+
     if (zend_parse_parameters(ZEND_NUM_ARGS() TSRMLS_CC, "s|lb", &host, &host_len, &port, &ssl) == FAILURE)
     {
         return;
@@ -350,10 +343,6 @@ void http2_add_cookie(nghttp2_nv *nv, int *index, zval *cookies TSRMLS_DC)
 
 int http2_client_parse_header(http2_client_property *hcc, http2_client_stream *stream , int flags, char *in, size_t inlen)
 {
-#if PHP_MAJOR_VERSION < 7
-    TSRMLS_FETCH_FROM_CTX(sw_thread_ctx ? sw_thread_ctx : NULL);
-#endif
-
     nghttp2_hd_inflater *inflater = hcc->inflater;
     zval *zresponse = stream->response_object;
     if (!inflater)
@@ -375,9 +364,7 @@ int http2_client_parse_header(http2_client_property *hcc, http2_client_stream *s
         inlen -= 5;
     }
 
-    zval *zheader;
-    SW_MAKE_STD_ZVAL(zheader);
-    array_init(zheader);
+    zval *headers = sw_zend_read_property_array(swoole_http2_response_class_entry_ptr, zresponse, ZEND_STRL("headers"), 1 TSRMLS_CC);
     zval *cookies = sw_zend_read_property_array(swoole_http2_response_class_entry_ptr, zresponse, ZEND_STRL("cookies"), 1 TSRMLS_CC);
     zval *set_cookie_headers = sw_zend_read_property_array(swoole_http2_response_class_entry_ptr, zresponse, ZEND_STRL("set_cookie_headers"), 1 TSRMLS_CC);
 
@@ -431,7 +418,7 @@ int http2_client_parse_header(http2_client_property *hcc, http2_client_stream *s
                 }
             }
 
-            sw_add_assoc_stringl_ex(zheader, (char *) nv.name, nv.namelen + 1, (char *) nv.value, nv.valuelen, 1);
+            sw_add_assoc_stringl_ex(headers, (char *) nv.name, nv.namelen + 1, (char *) nv.value, nv.valuelen, 1);
         }
 
         if (inflate_flags & NGHTTP2_HD_INFLATE_FINAL)
@@ -446,9 +433,6 @@ int http2_client_parse_header(http2_client_property *hcc, http2_client_stream *s
         }
     }
 
-    zend_update_property(swoole_http2_response_class_entry_ptr, zresponse, ZEND_STRL("headers"), zheader TSRMLS_CC);
-    sw_zval_ptr_dtor(&zheader);
-
     rv = nghttp2_hd_inflate_change_table_size(inflater, 4096);
     if (rv != 0)
     {
@@ -496,7 +480,7 @@ static int http2_client_onFrame(zval *zobject, zval *zdata TSRMLS_DC)
                 swTraceLog(SW_TRACE_HTTP2, "setting: max_concurrent_streams=%d.", value);
                 break;
             case SW_HTTP2_SETTINGS_INIT_WINDOW_SIZE:
-                hcc->window_size = value;
+                hcc->send_window = value;
                 swTraceLog(SW_TRACE_HTTP2, "setting: init_window_size=%d.", value);
                 break;
             case SW_HTTP2_SETTINGS_MAX_FRAME_SIZE:
@@ -522,8 +506,8 @@ static int http2_client_onFrame(zval *zobject, zval *zdata TSRMLS_DC)
     }
     else if (type == SW_HTTP2_TYPE_WINDOW_UPDATE)
     {
-        hcc->window_size = ntohl(*(int *) buf);
-        swTraceLog(SW_TRACE_HTTP2, "update: window_size=%d.", hcc->window_size);
+        hcc->send_window = ntohl(*(int *) buf);
+        swTraceLog(SW_TRACE_HTTP2, "update: window_size=%d.", hcc->send_window);
         return SW_OK;
     }
     else if (type == SW_HTTP2_TYPE_PING)
@@ -595,7 +579,7 @@ static int http2_client_onFrame(zval *zobject, zval *zdata TSRMLS_DC)
 
         if (stream->buffer)
         {
-            zend_update_property_stringl(swoole_http2_response_class_entry_ptr, stream->response_object, ZEND_STRL("body"), stream->buffer->str, stream->buffer->length TSRMLS_CC);
+            zend_update_property_stringl(swoole_http2_response_class_entry_ptr, stream->response_object, ZEND_STRL("data"), stream->buffer->str, stream->buffer->length TSRMLS_CC);
         }
 
         zval **args[1];
@@ -680,9 +664,6 @@ static void http2_client_set_callback(zval *zobject, const char *callback_name,
     SW_ZVAL_STRING(zname, callback_name, 1);
     SW_ZVAL_STRING(zmethod_name, method_name, 1);
 
-#if PHP_MAJOR_VERSION < 7
-    sw_zval_add_ref(&zobject);
-#endif
 
     add_next_index_zval(zcallback, zobject);
     add_next_index_zval(zcallback, zmethod_name);
@@ -1233,11 +1214,7 @@ static PHP_METHOD(swoole_http2_client, onConnect)
     http2_client_property *hcc = swoole_get_property(getThis(), HTTP2_CLIENT_PROPERTY_INDEX);
     hcc->ready = 1;
     hcc->stream_id = 1;
-    hcc->send_setting = 1;
-    if (hcc->send_setting)
-    {
-        http2_client_send_setting(cli);
-    }
+    http2_client_send_setting(cli);
     http2_client_send_all_requests(getThis() TSRMLS_CC);
 }
 
@@ -1265,6 +1242,8 @@ static PHP_METHOD(swoole_http2_client, onReceive)
 
 static PHP_METHOD(swoole_http2_client, __destruct)
 {
+    SW_PREVENT_USER_DESTRUCT;
+
     http2_client_property *hcc = swoole_get_property(getThis(), HTTP2_CLIENT_PROPERTY_INDEX);
     if (hcc)
     {
