@@ -123,7 +123,6 @@ static int http2_build_header(http_context *ctx, uchar *buffer, int body_length
 
     swServer *serv = SwooleG.serv;
 
-    char buf[SW_HTTP_HEADER_MAX_SIZE];
     char *date_str = NULL;
     char intbuf[2][16];
 
@@ -224,8 +223,8 @@ static int http2_build_header(http_context *ctx, uchar *buffer, int body_length
             body_length = swoole_zlib_buffer->length;
         }
 #endif
-        ret = swoole_itoa(buf, body_length);
-        http2_add_header(&nv[index++], ZEND_STRL("content-length"), buf, ret);
+        ret = swoole_itoa(intbuf[1], body_length);
+        http2_add_header(&nv[index++], ZEND_STRL("content-length"), intbuf[1], ret);
     }
     //http cookies
     if (ctx->response.zcookie)
@@ -290,14 +289,24 @@ static int http2_build_header(http_context *ctx, uchar *buffer, int body_length
 
 int swoole_http2_do_response(http_context *ctx, swString *body)
 {
-#if PHP_MAJOR_VERSION < 7
-    TSRMLS_FETCH_FROM_CTX(sw_thread_ctx ? sw_thread_ctx : NULL);
-#endif
-
     swoole_http_client *client = ctx->client;
     char header_buffer[8192];
     int ret;
 
+#ifdef SW_HAVE_ZLIB
+    if (ctx->gzip_enable)
+    {
+        if (body->length > 0)
+        {
+            swoole_http_response_compress(body, ctx->gzip_level);
+        }
+        else
+        {
+            ctx->gzip_enable = 0;
+        }
+    }
+#endif
+
     ret = http2_build_header(ctx, (uchar *) header_buffer, body->length TSRMLS_CC);
     swString_clear(swoole_http_buffer);
 
@@ -349,10 +358,23 @@ int swoole_http2_do_response(http_context *ctx, swString *body)
         goto _end;
     }
 
-    char *p = body->str;
-    size_t l = body->length;
+    char *p;
+    size_t l;
     size_t send_n;
 
+#ifdef SW_HAVE_ZLIB
+    if (ctx->gzip_enable)
+    {
+        p = swoole_zlib_buffer->str;
+        l = swoole_zlib_buffer->length;
+    }
+    else
+#endif
+    {
+        p = body->str;
+        l = body->length;
+    }
+
     while (l > 0)
     {
         int _send_flag;
@@ -412,10 +434,6 @@ int swoole_http2_do_response(http_context *ctx, swString *body)
 
 static int http2_parse_header(swoole_http_client *client, http_context *ctx, int flags, char *in, size_t inlen)
 {
-#if PHP_MAJOR_VERSION < 7
-    TSRMLS_FETCH_FROM_CTX(sw_thread_ctx ? sw_thread_ctx : NULL);
-#endif
-
     nghttp2_hd_inflater *inflater = client->inflater;
 
     if (!inflater)
@@ -569,10 +587,6 @@ static int http2_parse_header(swoole_http_client *client, http_context *ctx, int
  */
 int swoole_http2_onFrame(swoole_http_client *client, swEventData *req)
 {
-#if PHP_MAJOR_VERSION < 7
-    TSRMLS_FETCH_FROM_CTX(sw_thread_ctx ? sw_thread_ctx : NULL);
-#endif
-
     if (!client->init)
     {
         client->window_size = SW_HTTP2_DEFAULT_WINDOW_SIZE;
@@ -691,11 +705,7 @@ int swoole_http2_onFrame(swoole_http_client *client, swEventData *req)
         if (length > 0 && client->remote_window_size < SW_HTTP2_MAX_WINDOW_SIZE / 4)
         {
             char window_update_frame[SW_HTTP2_FRAME_HEADER_SIZE + SW_HTTP2_WINDOW_UPDATE_SIZE];
-            uint32_t increment_size = SW_HTTP2_MAX_WINDOW_SIZE - client->remote_window_size;
-            window_update_frame[0 + SW_HTTP2_FRAME_HEADER_SIZE] = increment_size >> 24;
-            window_update_frame[1 + SW_HTTP2_FRAME_HEADER_SIZE] = increment_size >> 16;
-            window_update_frame[2 + SW_HTTP2_FRAME_HEADER_SIZE] = increment_size >> 8;
-            window_update_frame[3 + SW_HTTP2_FRAME_HEADER_SIZE] = increment_size;
+            *(uint32_t*) ((char *) window_update_frame) = htonl(SW_HTTP2_MAX_WINDOW_SIZE - client->remote_window_size);
             swHttp2_set_frame_header(window_update_frame, SW_HTTP2_TYPE_WINDOW_UPDATE, SW_HTTP2_WINDOW_UPDATE_SIZE, 0, 0);
             swServer_tcp_send(SwooleG.serv, fd, window_update_frame, SW_HTTP2_FRAME_HEADER_SIZE + SW_HTTP2_WINDOW_UPDATE_SIZE);
             client->remote_window_size = SW_HTTP2_MAX_WINDOW_SIZE;
