@@ -418,6 +418,8 @@ static PHP_METHOD(swoole_redis, close)
 
 static PHP_METHOD(swoole_redis, __destruct)
 {
+    SW_PREVENT_USER_DESTRUCT;
+
     swRedisClient *redis = swoole_get_object(getThis());
     if (redis)
     {
@@ -568,17 +570,6 @@ static PHP_METHOD(swoole_redis, __call)
         redis->state = SWOOLE_REDIS_STATE_WAIT_RESULT;
         redis->reqnum++;
 
-#if PHP_MAJOR_VERSION < 7
-        zval *callback;
-        zval **cb_tmp;
-        if (zend_hash_index_find(Z_ARRVAL_P(params), zend_hash_num_elements(Z_ARRVAL_P(params)) - 1, (void **) &cb_tmp) == FAILURE)
-        {
-            swoole_php_error(E_WARNING, "index out of array bounds.");
-            FREE_MEM();
-            RETURN_FALSE;
-        }
-        callback = *cb_tmp;
-#else
         zval *callback = zend_hash_index_find(Z_ARRVAL_P(params), zend_hash_num_elements(Z_ARRVAL_P(params)) - 1);
         if (callback == NULL)
         {
@@ -586,7 +577,6 @@ static PHP_METHOD(swoole_redis, __call)
             FREE_MEM();
             RETURN_FALSE;
         }
-#endif
 
         sw_zval_add_ref(&callback);
         callback = sw_zval_dup(callback);
@@ -686,9 +676,6 @@ static void swoole_redis_parse_result(swRedisClient *redis, zval* return_value,
         array_init(return_value);
         for (j = 0; j < reply->elements; j++)
         {
-#if PHP_MAJOR_VERSION < 7
-            SW_ALLOC_INIT_ZVAL(val);
-#endif
             swoole_redis_parse_result(redis, val, reply->element[j] TSRMLS_CC);
             add_next_index_zval(return_value, val);
         }
@@ -703,9 +690,6 @@ static void swoole_redis_parse_result(swRedisClient *redis, zval* return_value,
 
 static void swoole_redis_onTimeout(swTimer *timer, swTimer_node *tnode)
 {
-#if PHP_MAJOR_VERSION < 7
-    TSRMLS_FETCH_FROM_CTX(sw_thread_ctx ? sw_thread_ctx : NULL);
-#endif
     swRedisClient *redis = tnode->data;
     zend_update_property_long(swoole_redis_class_entry_ptr, redis->object, ZEND_STRL("errCode"), ETIMEDOUT TSRMLS_CC);
     zend_update_property_string(swoole_redis_class_entry_ptr, redis->object, ZEND_STRL("errMsg"), strerror(ETIMEDOUT) TSRMLS_CC);
@@ -717,10 +701,6 @@ static void swoole_redis_onTimeout(swTimer *timer, swTimer_node *tnode)
 
 static void swoole_redis_onCompleted(redisAsyncContext *c, void *r, void *privdata)
 {
-#if PHP_MAJOR_VERSION < 7
-    TSRMLS_FETCH_FROM_CTX(sw_thread_ctx ? sw_thread_ctx : NULL);
-#endif
-
     swRedisClient *redis = c->ev.data;
     if (redis->state == SWOOLE_REDIS_STATE_CLOSED)
     {
@@ -781,10 +761,6 @@ static void swoole_redis_onCompleted(redisAsyncContext *c, void *r, void *privda
 
 static void swoole_redis_onResult(redisAsyncContext *c, void *r, void *privdata)
 {
-#if PHP_MAJOR_VERSION < 7
-    TSRMLS_FETCH_FROM_CTX(sw_thread_ctx ? sw_thread_ctx : NULL);
-#endif
-
     redisReply *reply = r;
     if (reply == NULL)
     {
@@ -842,9 +818,6 @@ static void swoole_redis_onResult(redisAsyncContext *c, void *r, void *privdata)
 
 void swoole_redis_onConnect(const redisAsyncContext *c, int status)
 {
-#if PHP_MAJOR_VERSION < 7
-    TSRMLS_FETCH_FROM_CTX(sw_thread_ctx ? sw_thread_ctx : NULL);
-#endif
     swRedisClient *redis = c->ev.data;
 
     if (redis->timer)
@@ -890,10 +863,6 @@ void swoole_redis_onClose(const redisAsyncContext *c, int status)
     redis->state = SWOOLE_REDIS_STATE_CLOSED;
     redis->context = NULL;
 
-#if PHP_MAJOR_VERSION < 7
-    TSRMLS_FETCH_FROM_CTX(sw_thread_ctx ? sw_thread_ctx : NULL);
-#endif
-
     zval *zcallback = sw_zend_read_property(swoole_redis_class_entry_ptr, redis->object, ZEND_STRL("onClose"), 1 TSRMLS_CC);
     if (zcallback && !ZVAL_IS_NULL(zcallback))
     {
@@ -919,9 +888,6 @@ void swoole_redis_onClose(const redisAsyncContext *c, int status)
 
 static int swoole_redis_onError(swReactor *reactor, swEvent *event)
 {
-#if PHP_MAJOR_VERSION < 7
-        TSRMLS_FETCH_FROM_CTX(sw_thread_ctx ? sw_thread_ctx : NULL);
-#endif
     swRedisClient *redis = event->socket->object;
     zval *zcallback = sw_zend_read_property(swoole_redis_class_entry_ptr, redis->object, ZEND_STRL("onConnect"), 0 TSRMLS_CC);
 
