@@ -196,43 +196,47 @@ static int redis_onReceive(swServer *serv, swEventData *req)
     SW_MAKE_STD_ZVAL(zfd);
     ZVAL_LONG(zfd, fd);
 
-#ifndef SW_COROUTINE
-    zval **args[2];
-    zval *zcallback = sw_zend_read_property(swoole_redis_server_class_entry_ptr, zobject, _command, _command_len, 1 TSRMLS_CC);
-    if (!zcallback || ZVAL_IS_NULL(zcallback))
+    if (SwooleG.enable_coroutine)
     {
-        length = snprintf(err_msg, sizeof(err_msg), "-ERR unknown command '%*s'\r\n", command_len, command);
-        swServer_tcp_send(serv, fd, err_msg, length);
-        return SW_OK;
-    }
-    args[0] = &zfd;
-    args[1] = &zparams;
+        zval *index = sw_zend_read_property(swoole_redis_server_class_entry_ptr, zobject, _command, _command_len, 1 TSRMLS_CC);
+        if (!index || ZVAL_IS_NULL(index))
+        {
+            length = snprintf(err_msg, sizeof(err_msg), "-ERR unknown command '%*s'\r\n", command_len, command);
+            swServer_tcp_send(serv, fd, err_msg, length);
+            return SW_OK;
+        }
+        zval *args[2];
+        args[0] = zfd;
+        args[1] = zparams;
 
-    if (sw_call_user_function_ex(EG(function_table), NULL, zcallback, &retval, 2, args, 0, NULL TSRMLS_CC) == FAILURE)
-    {
-        swoole_php_error(E_WARNING, "command handler error.");
+        zend_fcall_info_cache *cache = func_cache_array.array[Z_LVAL_P(index)];
+        if (coro_create(cache, args, 2, &retval, NULL, NULL) < 0)
+        {
+            sw_zval_ptr_dtor(&zfd);
+            sw_zval_ptr_dtor(&zdata);
+            sw_zval_ptr_dtor(&zparams);
+            return SW_OK;
+        }
     }
-#else
-    zval *index = sw_zend_read_property(swoole_redis_server_class_entry_ptr, zobject, _command, _command_len, 1 TSRMLS_CC);
-    if (!index || ZVAL_IS_NULL(index))
+    else
     {
-        length = snprintf(err_msg, sizeof(err_msg), "-ERR unknown command '%*s'\r\n", command_len, command);
-        swServer_tcp_send(serv, fd, err_msg, length);
-        return SW_OK;
-    }
-    zval *args[2];
-    args[0] = zfd;
-    args[1] = zparams;
+        zval **args[2];
+        zval *zcallback = sw_zend_read_property(swoole_redis_server_class_entry_ptr, zobject, _command, _command_len, 1 TSRMLS_CC);
+        if (!zcallback || ZVAL_IS_NULL(zcallback))
+        {
+            length = snprintf(err_msg, sizeof(err_msg), "-ERR unknown command '%*s'\r\n", command_len, command);
+            swServer_tcp_send(serv, fd, err_msg, length);
+            return SW_OK;
+        }
+        args[0] = &zfd;
+        args[1] = &zparams;
 
-    zend_fcall_info_cache *cache = func_cache_array.array[Z_LVAL_P(index)];
-    if (coro_create(cache, args, 2, &retval, NULL, NULL) != 0)
-    {
-        sw_zval_ptr_dtor(&zfd);
-        sw_zval_ptr_dtor(&zdata);
-        sw_zval_ptr_dtor(&zparams);
-        return SW_OK;
+        if (sw_call_user_function_ex(EG(function_table), NULL, zcallback, &retval, 2, args, 0, NULL TSRMLS_CC) == FAILURE)
+        {
+            swoole_php_error(E_WARNING, "command handler error.");
+        }
     }
-#endif
+
     if (EG(exception))
     {
         zend_exception_error(EG(exception), E_ERROR TSRMLS_CC);
@@ -256,13 +260,13 @@ static PHP_METHOD(swoole_redis_server, start)
 {
     int ret;
 
-    if (SwooleGS->start > 0)
+    swServer *serv = swoole_get_object(getThis());
+    if (serv->gs->start > 0)
     {
         swoole_php_error(E_WARNING, "Server is running. Unable to execute swoole_server::start.");
         RETURN_FALSE;
     }
 
-    swServer *serv = swoole_get_object(getThis());
     php_swoole_register_callback(serv);
 
     serv->onReceive = redis_onReceive;
@@ -392,7 +396,7 @@ static PHP_METHOD(swoole_redis_server, format)
         if (value)
         {
             convert_to_string(value);
-            length = snprintf(message, sizeof(message), "+%*s\r\n", Z_STRLEN_P(value), Z_STRVAL_P(value));
+            length = snprintf(message, sizeof(message), "+%*s\r\n", (int)Z_STRLEN_P(value), Z_STRVAL_P(value));
         }
         else
         {
@@ -405,7 +409,7 @@ static PHP_METHOD(swoole_redis_server, format)
         if (value)
         {
             convert_to_string(value);
-            length = snprintf(message, sizeof(message), "-%*s\r\n", Z_STRLEN_P(value), Z_STRVAL_P(value));
+            length = snprintf(message, sizeof(message), "-%*s\r\n", (int)Z_STRLEN_P(value), Z_STRVAL_P(value));
         }
         else
         {
@@ -421,7 +425,7 @@ static PHP_METHOD(swoole_redis_server, format)
         }
 
         convert_to_long(value);
-        length = snprintf(message, sizeof(message), ":%d\r\n", Z_LVAL_P(value));
+        length = snprintf(message, sizeof(message), ":%zd\r\n", Z_LVAL_P(value));
         SW_RETURN_STRINGL(message, length, 1);
     }
     else if (type == SW_REDIS_REPLY_STRING)
@@ -439,7 +443,7 @@ static PHP_METHOD(swoole_redis_server, format)
             RETURN_FALSE;
         }
         swString_clear(format_buffer);
-        length = snprintf(message, sizeof(message), "$%d\r\n", Z_STRLEN_P(value));
+        length = snprintf(message, sizeof(message), "$%zd\r\n", Z_STRLEN_P(value));
         swString_append_ptr(format_buffer, message, length);
         swString_append_ptr(format_buffer, Z_STRVAL_P(value), Z_STRLEN_P(value));
         swString_append_ptr(format_buffer, SW_CRLF, SW_CRLF_LEN);
@@ -470,7 +474,7 @@ static PHP_METHOD(swoole_redis_server, format)
             }
 #endif
             convert_to_string(item);
-            length = snprintf(message, sizeof(message), "$%d\r\n", Z_STRLEN_P(item));
+            length = snprintf(message, sizeof(message), "$%zd\r\n", Z_STRLEN_P(item));
             swString_append_ptr(format_buffer, message, length);
             swString_append_ptr(format_buffer, Z_STRVAL_P(item), Z_STRLEN_P(item));
             swString_append_ptr(format_buffer, SW_CRLF, SW_CRLF_LEN);
@@ -517,7 +521,7 @@ static PHP_METHOD(swoole_redis_server, format)
             }
 #endif
             convert_to_string(item);
-            length = snprintf(message, sizeof(message), "$%d\r\n%s\r\n$%d\r\n", keylen, key, Z_STRLEN_P(item));
+            length = snprintf(message, sizeof(message), "$%d\r\n%s\r\n$%zd\r\n", keylen, key, Z_STRLEN_P(item));
             swString_append_ptr(format_buffer, message, length);
             swString_append_ptr(format_buffer, Z_STRVAL_P(item), Z_STRLEN_P(item));
             swString_append_ptr(format_buffer, SW_CRLF, SW_CRLF_LEN);
